@@ -19,17 +19,24 @@
 #
 # regenwolken is a CloudApp clone that works on your very own server.
 
-__version__ = '0.6.0'
+__version__ = '0.6.1'
 
 import sys
 import logging
 
+from SocketServer import ThreadingMixIn
+from wsgiref.simple_server import WSGIServer, make_server
+
 import flask
 import pymongo
 
 from regenwolken import views, mongonic
 
 
+class ThreadedWSGIServer(ThreadingMixIn, WSGIServer):
+    pass
+
+
 class Regenwolken(flask.Flask):
 
     def __init__(self):
@@ -86,6 +93,9 @@ class Regenwolken(flask.Flask):
             self.config['MONGODB_PORT']
         )[self.config['MONGODB_NAME']]
 
+        if self.config.get('MONGODB_USER') and self.get('MONGODB_PASSW'):
+            conf.authenticate(self.config['MONGODB_USER'], self.config['MONGODB_PASS'])
+
         con.items.create_index('short_id')
         con.accounts.create_index('email')
 
@@ -131,4 +141,7 @@ class Regenwolken(flask.Flask):
 def main():
 
     app = Regenwolken()
-    app.run(host=app.config['BIND_ADDRESS'], port=app.config['PORT'])
+    httpd = make_server(
+        app.config['BIND_ADDRESS'], app.config['PORT'],
+        app, server_class=ThreadedWSGIServer)
+    httpd.serve_forever()
